@@ -7,6 +7,7 @@ import typing
 from enum import Enum
 from pathlib import Path
 import shutil
+import tarfile
 
 from . import vivado_hls_tcl as vtcl
 from . import vivado_report as vrpt
@@ -25,10 +26,12 @@ class ExperienceType(Enum):
     IMPLEMENTATION = 2
 
 def build_get_hls(exp):
-    pwd = str(Path().resolve())
+    pwd = Path().resolve()
     def get_hl_files():
-        export_path = Path(f"./vivado_hls_synthesis/solution/syn/{exp._hdl.get_name()}/{exp._comp_name}.{exp._hdl.get_extension()}")
-        shutil.move(str(export_path.resolve()), str(pwd))
+        export_path = Path(f"./vivado_hls_synthesis/solution/syn/{exp._hdl.get_name()}/")#{exp._comp_name}.{exp._hdl.get_extension()}")
+        with tarfile.open(pwd/f"{exp.name}.tar.xz", "w:xz") as outfile:
+            for source in export_path.glob(f"*.{exp._hdl.get_extension()}"):
+                outfile.add(str(source), arcname=source.name)
     return get_hl_files
 
 def build_get_export_ip(exp):
